from scribe import cadoles
from os.path import dirname, abspath, join, isdir
from shutil import rmtree
from os import makedirs, stat

TEST_DIR = dirname(abspath(__file__))
cadoles.PATH_SCRIPTS = join(TEST_DIR, 'scripts')
cadoles.SMB_SERVEUR = 'test'

def test_get_scripts_list():
    list1 = cadoles.get_scripts_list('cadoles', 'scribe', 'CIFSFS',
            ['eleves', '6eme', '6eme2'])
    list2 = []
    for l in ['/users/cadoles.txt', '/machines/scribe.txt',
            '/groups/eleves.txt', '/os/CIFSFS/eleves.txt', '/groups/6eme.txt',
            '/os/CIFSFS/6eme.txt', '/groups/6eme2.txt', '/os/CIFSFS/6eme2.txt',
            '/os/CIFSFS.txt', '/os/CIFSFS/cadoles.txt']:
        list2.append('%s%s' % (cadoles.PATH_SCRIPTS, l))
    assert list1 == list2

def test_gen_cmd_line():
    ret1 = cadoles.gen_cmd_line('c:\\\\notepad.exe')
    ret2 = 'cmd,c:\\\\notepad.exe\r\n'
    assert ret1 == ret2
    ret1 = cadoles.gen_cmd_line('c:\\\\notepad.exe', True)
    ret2 = 'cmd,c:\\\\notepad.exe,HIDDEN\r\n'
    assert ret1 == ret2
    ret1 = cadoles.gen_cmd_line('c:\\\\notepad.exe', False, True)
    ret2 = 'cmd,c:\\\\notepad.exe,NOWAIT\r\n'
    assert ret1 == ret2
    ret1 = cadoles.gen_cmd_line('c:\\\\notepad.exe', True, True)
    ret2 = 'cmd,c:\\\\notepad.exe,HIDDEN,NOWAIT\r\n'
    assert ret1 == ret2

def test_gen_cmd_line_win95():
    ret1 = cadoles.gen_cmd_line_win95('c:\\\\notepad.exe')
    ret2 = 'c:\\\\notepad.exe\r\n'
    assert ret1 == ret2

def test_gen_letter_share():
    ret1 = cadoles.gen_letter_share('c:', '\\\\test\\test')
    ret2 = ('c', '\\\\test\\test')
    assert ret1 == ret2
    ret1 = cadoles.gen_letter_share('c:', '\\\\test\\test\\')
    assert ret1 == ret2
    ret1 = cadoles.gen_letter_share('c', '\\\\test\\test\\')
    assert ret1 == ret2

def test_gen_lecteur_bloc():
    ret1 = cadoles.gen_lecteur_bloc('c:', '\\\\test\\test')
    ret2 = 'lecteur,c:,\\\\test\\test\r\n'
    assert ret1 == ret2
    ret1 = cadoles.gen_lecteur_bloc('c:', '\\\\test\\test\\')
    assert ret1 == ret2
    ret1 = cadoles.gen_lecteur_bloc('c', '\\\\test\\test\\')
    assert ret1 == ret2

def test_gen_lecteur_bloc_win95():
    ret1 = cadoles.gen_lecteur_bloc_win95('c:', '\\\\test\\test')
    ret2 = 'IF EXIST c:\\nul goto errctest\r\nNET USE  c: \\\\test\\test\r\ngoto suitctest\r\n:errctest\r\nNET USE  * \\\\test\\test\r\n:suitctest\r\n'
    assert ret1 == ret2
    ret1 = cadoles.gen_lecteur_bloc_win95('c', '\\\\test\\test\\')
    assert ret1 == ret2

def test_gen_vnc_line():
    ret1 = cadoles.gen_vnc_line('eleve')
    ret2 = 'regedit /s \\\\test\\netlogon\\scripts\\os\\Win95\\vnc_controle.reg\r\n%windir%\\eole\\ultravnc\\winvnc -kill\r\n%windir%\\eole\\ultravnc\\winvnc -service\r\n'
    assert ret1 == ret2
    ret1 = cadoles.gen_vnc_line('enseignant')
    ret2 = 'regedit /s \\\\test\\netlogon\\scripts\\os\\Win95\\vnc_controle.reg\r\n%windir%\\eole\\ultravnc\\winvnc -kill\r\n'
    assert ret1 == ret2
    ret1 = cadoles.gen_vnc_line('unknown')
    assert ret1 == ret2

def test_gen_esu():
    ret1 = cadoles.gen_esu()
    ret2 = "\\\\test\\ESU\\Base\\esuclnt.exe\r\n"
    assert ret1 == ret2

def test_parse_line():
    #lecteur
    ret1 = cadoles.parse_line('CIFSFS', 'lecteur,c,\\\\test\\test')
    ret2 = 'lecteur,c:,\\\\test\\test\r\n'
    assert ret1 == ret2
    ret1 = cadoles.parse_line('Win95', 'lecteur,c,\\\\test\\test')
    ret2 = 'IF EXIST c:\\nul goto errctest\r\nNET USE  c: \\\\test\\test\r\ngoto suitctest\r\n:errctest\r\nNET USE  * \\\\test\\test\r\n:suitctest\r\n'
    assert ret1 == ret2
    #cmd
    ret1 = cadoles.parse_line('CIFSFS', 'cmd,c:\\\\notepad.exe')
    ret2 = 'cmd,c:\\\\notepad.exe\r\n'
    assert ret1 == ret2
    ret1 = cadoles.parse_line('CIFSFS', 'cmd,c:\\\\notepad.exe,HIDDEN')
    ret2 = 'cmd,c:\\\\notepad.exe,HIDDEN\r\n'
    assert ret1 == ret2
    ret1 = cadoles.parse_line('CIFSFS', 'cmd,c:\\\\notepad.exe,NOWAIT')
    ret2 = 'cmd,c:\\\\notepad.exe,NOWAIT\r\n'
    assert ret1 == ret2
    ret1 = cadoles.parse_line('CIFSFS', 'cmd,c:\\\\notepad.exe,HIDDEN,NOWAIT')
    ret2 = 'cmd,c:\\\\notepad.exe,HIDDEN,NOWAIT\r\n'
    assert ret1 == ret2
    ret1 = cadoles.parse_line('CIFSFS', 'cmd,c:\\\\notepad.exe,ERROR')
    ret2 = 'cmd,c:\\\\notepad.exe\r\n'
    assert ret1 == ret2

    ret1 = cadoles.parse_line('Win95', 'cmd,c:\\\\notepad.exe')
    ret2 = 'c:\\\\notepad.exe\r\n'
    assert ret1 == ret2
    ret1 = cadoles.parse_line('Win95', 'cmd,c:\\\\notepad.exe,HIDDEN')
    assert ret1 == ret2
    ret1 = cadoles.parse_line('Win95', 'cmd,c:\\\\notepad.exe,NOWAIT')
    assert ret1 == ret2
    ret1 = cadoles.parse_line('Win95', 'cmd,c:\\\\notepad.exe,HIDDEN,NOWAIT')
    assert ret1 == ret2
    ret1 = cadoles.parse_line('Win95', 'cmd,c:\\\\notepad.exe,ERROR')
    assert ret1 == ret2
    #error
    ret1 = cadoles.parse_line('CIFSFS', 'error,c,\\\\test\\test')
    ret2 = ''
    assert ret1 == ret2

def test_get_scripts():
    ret1 = cadoles.get_scripts('cadoles', 'scribe', 'CIFSFS',
            ['eleves', '6eme', '6eme2'])
    ret2 = ('lecteur,c:,\\\\test\\test\r\n',
            'cmd,c:\\\\notepad.exe,NOWAIT\r\n')
    assert ret1 == ret2
    ret1 = cadoles.get_scripts('cadoles', 'scribe', 'Win95',
            ['eleves', '6eme', '6eme2'])
    ret2 = ('IF EXIST c:\\nul goto errctest\r\nNET USE  c: \\\\test\\test\r\ngoto suitctest\r\n:errctest\r\nNET USE  * \\\\test\\test\r\n:suitctest\r\n', 'c:\\\\notepad.exe\r\n')
    assert ret1 == ret2

def test_write_fich():
    tmp_dir = join(TEST_DIR, 'tmp')
    tmp_file = join(tmp_dir, 'script.txt')
    if isdir(tmp_dir):
        rmtree(tmp_dir)
    makedirs(tmp_dir)
    content = 'IF EXIST c:\\nul goto errctest\r\nNET USE  c: \\\\test\\test\r\ngoto suitctest\r\n:errctest\r\nNET USE  * \\\\test\\test\r\n:suitctest\r\nc:\\\\notepad.exe\r\n'
    cadoles.write_fich(tmp_file, content)
    assert open(tmp_file, 'r').read() == content
    # tester les permissions
    assert stat(tmp_file).st_mode == 33188
    assert stat(tmp_file).st_uid == 0
    assert stat(tmp_file).st_gid == 0

def test_gen_fich():
    tmp_dir = join(TEST_DIR, 'tmp')
    tmp_file = join(tmp_dir, 'script.txt')
    if isdir(tmp_dir):
        rmtree(tmp_dir)
    makedirs(tmp_dir)
    user = 'cadoles'
    groups = ['eleves', '6eme', '6eme2']
    shares = [{'drive': '', 'uri': '\\\\test\\test'},
            {'drive': 'd:', 'uri': '\\\\test\\test2'},
            {'drive': 'e', 'uri': '\\\\test\\test3'},
            {'drive': 'f', 'uri': '\\\\test\\test4\\'}]
    machine = 'scribe'
    ostype = 'CIFSFS'
    homedrive = 'u:'
    userclass = 'eleve'
    netlogon = tmp_file
    cadoles.gen_fich(user, groups, shares, machine, ostype, homedrive,
            userclass, netlogon)
    content = 'lecteur,c:,\\\\test\\test\r\nlecteur,d:,\\\\test\\test2\r\nlecteur,e:,\\\\test\\test3\r\nlecteur,f:,\\\\test\\test4\r\ncmd,c:\\\\notepad.exe,NOWAIT\r\n'
    assert open(tmp_file, 'r').read() == content
    userclass = 'enseignant'
    cadoles.gen_fich(user, groups, shares, machine, ostype, homedrive,
            userclass, netlogon)
    assert open(tmp_file, 'r').read() == content
    userclass = 'administratif'
    cadoles.gen_fich(user, groups, shares, machine, ostype, homedrive,
            userclass, netlogon)
    assert open(tmp_file, 'r').read() == content

    ostype = 'Win95'
    userclass = 'eleve'
    cadoles.gen_fich(user, groups, shares, machine, ostype, homedrive,
            userclass, netlogon)
    content = 'IF EXIST c:\\nul goto errctest\r\nNET USE  c: \\\\test\\test\r\ngoto suitctest\r\n:errctest\r\nNET USE  * \\\\test\\test\r\n:suitctest\r\nIF EXIST d:\\nul goto errdtest2\r\nNET USE  d: \\\\test\\test2\r\ngoto suitdtest2\r\n:errdtest2\r\nNET USE  * \\\\test\\test2\r\n:suitdtest2\r\nIF EXIST e:\\nul goto erretest3\r\nNET USE  e: \\\\test\\test3\r\ngoto suitetest3\r\n:erretest3\r\nNET USE  * \\\\test\\test3\r\n:suitetest3\r\nIF EXIST f:\\nul goto errftest4\r\nNET USE  f: \\\\test\\test4\r\ngoto suitftest4\r\n:errftest4\r\nNET USE  * \\\\test\\test4\r\n:suitftest4\r\nIF EXIST u:\\nul goto erruPERSO\r\nNET USE  u: \\\\test\\PERSO\r\ngoto suituPERSO\r\n:erruPERSO\r\nNET USE  * \\\\test\\PERSO\r\n:suituPERSO\r\nregedit /s \\\\test\\netlogon\\scripts\\os\\Win95\\vnc_controle.reg\r\n%windir%\\eole\\ultravnc\\winvnc -kill\r\n%windir%\\eole\\ultravnc\\winvnc -service\r\n\\\\test\\ESU\\Base\\esuclnt.exe\r\nc:\\\\notepad.exe\r\n'
    assert open(tmp_file, 'r').read() == content
    userclass = 'enseignant'
    cadoles.gen_fich(user, groups, shares, machine, ostype, homedrive,
            userclass, netlogon)
    content = 'IF EXIST c:\\nul goto errctest\r\nNET USE  c: \\\\test\\test\r\ngoto suitctest\r\n:errctest\r\nNET USE  * \\\\test\\test\r\n:suitctest\r\nIF EXIST d:\\nul goto errdtest2\r\nNET USE  d: \\\\test\\test2\r\ngoto suitdtest2\r\n:errdtest2\r\nNET USE  * \\\\test\\test2\r\n:suitdtest2\r\nIF EXIST e:\\nul goto erretest3\r\nNET USE  e: \\\\test\\test3\r\ngoto suitetest3\r\n:erretest3\r\nNET USE  * \\\\test\\test3\r\n:suitetest3\r\nIF EXIST f:\\nul goto errftest4\r\nNET USE  f: \\\\test\\test4\r\ngoto suitftest4\r\n:errftest4\r\nNET USE  * \\\\test\\test4\r\n:suitftest4\r\nIF EXIST u:\\nul goto erruPERSO\r\nNET USE  u: \\\\test\\PERSO\r\ngoto suituPERSO\r\n:erruPERSO\r\nNET USE  * \\\\test\\PERSO\r\n:suituPERSO\r\nregedit /s \\\\test\\netlogon\\scripts\\os\\Win95\\vnc_controle.reg\r\n%windir%\\eole\\ultravnc\\winvnc -kill\r\n\\\\test\\ESU\\Base\\esuclnt.exe\r\nc:\\\\notepad.exe\r\n'
    assert open(tmp_file, 'r').read() == content
    userclass = 'administratif'
    cadoles.gen_fich(user, groups, shares, machine, ostype, homedrive,
            userclass, netlogon)
    assert open(tmp_file, 'r').read() == content

